Struct rkyv::with::Raw [−][src]
pub struct Raw;Expand description
A wrapper that provides an optimized bulk data array. This is primarily intended for large amounts of raw data, like bytes, floats, or integers.
This wrapper can be used with containers like Vec, but care must be taken to ensure that they
contain copy-safe types. Copy-safe types must be trivially copyable (have the same archived and
unarchived representations) and contain no padding bytes. In situations where copying
uninitialized bytes the output is acceptable, this wrapper may be used with containers of types
that contain padding bytes.
Unlike CopyOptimize, this wrapper will also skip validation for its elements. If the
elements of the container can have any invalid bit patterns (e.g. char, bool, complex
containers, etc.), then using Raw in an insecure setting can lead to undefined behavior. Take
great caution!
Safety
Using this wrapper with containers containing non-copy-safe types or types that require validation may result in undefined behavior.
Example
use rkyv::{Archive, with::Raw};
#[derive(Archive)]
struct Example {
#[with(Raw)]
bytes: Vec<u8>,
#[with(Raw)]
vertices: Vec<[f32; 3]>,
}Trait Implementations
type Archived = RawArchivedVec<T::Archived>
type Archived = RawArchivedVec<T::Archived>
The archived type of a With<F, Self>.
type Resolver = VecResolver
type Resolver = VecResolver
The resolver of a With<F, Self>.
impl<T, D> DeserializeWith<ArchivedVec<<T as Archive>::Archived>, Vec<T, Global>, D> for Raw where
T: Archive,
T::Archived: Deserialize<T, D>,
D: Fallible + ?Sized,
impl<T, D> DeserializeWith<ArchivedVec<<T as Archive>::Archived>, Vec<T, Global>, D> for Raw where
T: Archive,
T::Archived: Deserialize<T, D>,
D: Fallible + ?Sized,
Deserializes the field type F using the given deserializer.